==> molview_messages-0.9.0.tar.gz: lib/src/dataserver/table.dart <==
// Copyright (c) 2016, Herman Bergwerf. All rights reserved.
// Use of this source code is governed by an AGPL-3.0-style license
// that can be found in the LICENSE file.

part of molview_messages.dataserver;

/// Data table
class TableDescriptor {
  /// Data is retrieved from a remote source.
  final bool remote;

  /// Data is computed rather than retrieved from a storage.
  final bool computed;

  /// Data should be cached locally by the DataServer.
  final bool localCache;

  /// Primary key
  final PrimaryKey primaryKey;

  /// Secondary table keys
  final List<TableKey> keys;

  /// Table values
  final List<TableValue> values;

  /// Parameters that are required to request data.
  final Set<String> parameters;

  /// Constructor
  const TableDescriptor(
      {this.remote,
      this.computed,
      this.localCache,
      this.primaryKey,
      this.keys,
      this.values,
      this.parameters});

  /// Construct from PDS.
  factory TableDescriptor.fromPds(Map<String, dynamic> data) {
    var keys = data['keys'] as List<Map<String, dynamic>>;
    var values = data['values'] as List<Map<String, dynamic>>;
    return new TableDescriptor(
        remote: data['remote'] as bool,
        computed: data['computed'] as bool,
        localCache: data['localCache'] as bool,
        primaryKey:
            new PrimaryKey.fromPds(data['primaryKey'] as Map<String, dynamic>),
        keys: new List<TableKey>.generate(
            keys.length, (int i) => new TableKey.fromPds(keys[i])),
        values: new List<TableValue>.generate(
            values.length, (int i) => new TableValue.fromPds(values[i])),
        parameters: (data['parameters'] as List<String>).toSet());
  }

  /// Convert to PDS.
  Map<String, dynamic> toPds() {
    return {
      'remote': remote,
      'computed': computed,
      'localCache': localCache,
      'primaryKey': primaryKey.toPds(),
      'keys': pdsFromList(keys),
      'values': pdsFromList(values),
      'parameters': pdsFromSet(parameters)
    };
  }
}

==> molview_messages-0.10.0.tar.gz: lib/src/dataserver/table.dart <==
// Copyright (c) 2016, Herman Bergwerf. All rights reserved.
// Use of this source code is governed by an AGPL-3.0-style license
// that can be found in the LICENSE file.

part of molview_messages.dataserver;

/// Data table
class TableDescriptor {
  /// Data is retrieved from a remote source.
  final bool remote;

  /// Data is computed rather than retrieved from a storage.
  final bool computed;

  /// Data should be cached locally by the DataServer.
  final bool localCache;

  /// Primary key
  final PrimaryKey primaryKey;

  /// Secondary table keys
  final List<TableKey> keys;

  /// Table values
  final List<TableProperty> properties;

  /// Parameters that are required to request data.
  final Set<String> parameters;

  /// Constructor
  const TableDescriptor(
      {this.remote,
      this.computed,
      this.localCache,
      this.primaryKey,
      this.keys,
      this.properties,
      this.parameters});

  /// Construct from PDS.
  factory TableDescriptor.fromPds(Map<String, dynamic> data) {
    var keys = data['keys'] as List<Map<String, dynamic>>;
    var properties = data['properties'] as List<Map<String, dynamic>>;
    return new TableDescriptor(
        remote: data['remote'] as bool,
        computed: data['computed'] as bool,
        localCache: data['localCache'] as bool,
        primaryKey:
            new PrimaryKey.fromPds(data['primaryKey'] as Map<String, dynamic>),
        keys: new List<TableKey>.generate(
            keys.length, (int i) => new TableKey.fromPds(keys[i])),
        properties: new List<TableProperty>.generate(properties.length,
            (int i) => new TableProperty.fromPds(properties[i])),
        parameters: (data['parameters'] as List<String>).toSet());
  }

  /// Convert to PDS.
  Map<String, dynamic> toPds() {
    return {
      'remote': remote,
      'computed': computed,
      'localCache': localCache,
      'primaryKey': primaryKey.toPds(),
      'keys': pdsFromList(keys),
      'properties': pdsFromList(properties),
      'parameters': pdsFromSet(parameters)
    };
  }
}
